from __future__ import unicode_literals

import logging
from google.appengine.api import urlfetch
from requests_toolbelt.adapters import appengine

from . import get as base_get
from . import put as base_put
from . import post as base_post


logger = logging.getLogger(__name__)

appengine.monkeypatch()


def get(url, headers, key_location, fetch_deadline=15):
    urlfetch.set_default_fetch_deadline(fetch_deadline)

    return base_get(url=url, headers=headers, key_location=key_location)


def put(url, headers, key_location, data, fetch_deadline=15):
    urlfetch.set_default_fetch_deadline(fetch_deadline)

    return base_put(url=url, headers=headers, key_location=key_location, data=data)


def post(url, headers, key_location, data, fetch_deadline=15):
    urlfetch.set_default_fetch_deadline(fetch_deadline)

    return base_post(url=url, headers=headers, key_location=key_location, data=data)



from __future__ import unicode_literals

import logging
import requests

from drf_otp_permissions.headers import add_otp


logger = logging.getLogger(__name__)


def get(url, headers, key_location):
    headers_with_otp = add_otp({}, key_location, headers)

    response = requests.put(url=url, headers=headers_with_otp)

    logger.info(response.status_code)
    logger.info(response.text)

    return response


def put(url, headers, key_location, data):
    headers_with_otp = add_otp(data, key_location, headers)

    response = requests.put(url=url, headers=headers_with_otp, data=data)

    logger.info(response.status_code)
    logger.info(response.text)

    return response


def post(url, headers, key_location, data):
    headers_with_otp = add_otp(data, key_location, headers)

    response = requests.post(url=url, headers=headers_with_otp, data=data)

    logger.info(response.status_code)
    logger.info(response.text)

    return response



from setuptools import setup

setup(name='drf_otp_requests',
      version='0.2',
      description='requests for API with OTP permission',
      keywords='django rest framework drf otp permission requests',
      url='https://gitlab.com/taelimoh/drf-otp-requests',
      author='Tae-lim Oh',
      author_email='taelimoh@gmail.com',
      license='MIT',
      packages=['drf_otp_requests'],
      install_requires=[
            'requests==2.18.4',
            'requests-toolbelt==0.8.0',
            'drf-otp-permissions==0.3.1',
            'drf-logged-validation-error==0.1'
      ],
      test_suite='nose.collector',
      tests_require=['nose'],
      zip_safe=False)